@@ -1,6 +1,6 @@
 /* atmsigd.c - ATM signaling demon */
 
-/* Written 1995-1998 by Werner Almesberger, EPFL-LRC/ICA */
+/* Written 1995-1999 by Werner Almesberger, EPFL-LRC/ICA */
 
 
 #include <stdlib.h>
@@ -339,7 +339,22 @@ int main(int argc,char **argv)
 	    diag(COMPONENT,DIAG_FATAL,"Error in config file. - Aborting.");
     if (!atmpvc_addr_in_use(_entity.signaling_pvc))
 	_entity.signaling_pvc.sap_addr.vci = 5;
-    if (!_entity.uni) _entity.uni = S_UNI30;
+    if (!_entity.uni)
+	_entity.uni =
+#ifdef UNI31
+	    S_UNI31
+#ifdef ALLOW_UNI30
+	    | S_UNI30
+#endif
+#elif defined(UNI40)
+	    S_UNI40
+#ifdef Q2963_1
+	    | S_Q2963_1
+#endif
+#else
+	    S_UNI30
+#endif
+	    ;
     /* process all other options but -c */
     optind = 0;
     while ((c = getopt(argc,argv,"Abc:dD:l:m:nNP:q:t:")) != EOF)
